/*
**  nodelist.h
**
**  Structure for the FrontDoor Nodelist Database
**
**  Copyright 1993 Joaquim Homrighausen; All rights reserved.
**
**  Last revised: 93-06-28                    FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __NODELIST_H__
#define __NODELIST_H__

#ifdef __cplusplus
extern "C" {
#endif

/*
**  The FrontDoor Nodelist Database (FDND) uses a Pascal product from
**  Borland that has, unfortunately, been discontinued. It is called
**  "Turbo Database Toolkit" and works in a similar fashion to that of
**  many B+ filer toolkits.
**
**  This header file does not make an attempt to document the B+ file
**  structures, but only those fixed structures used by FrontDoor. For
**  owners of the Borland toolkit, the "TACCESS parameters" are listed
**  below.
**
**    NodeRecSize       = 178
**    FileHeaderSize    = 14
**    MinDataRecSize    = 14
**    MaxHeight         = 5
**    MaxDataRecSize    = 178
**    MaxKeyLen         = 24
**    PageSize          = 32
**    Order             = 16
**    PageStackSize     = 5
**    ItemOverhead      = 9
**    PageOverhead      = 5
*/

/*
**  NODEFILE.FDX contains some information about the Nodelist Database.
**
**  The information starts at offset 0x100 and is as follows:
**
**    Current nodelist extension          4 chars         (Pascal)
**    Nodelist Database revision         16 bit
**    Swedish pulse dial translation      1 byte
**
**  At offset 0x110, a set of the currently compiled zones is listed.
*/

/*
**  The private Nodelist Database (FDNODE.FDA) has the following record
**  format. Note that the char[] fields are in Pascal fashion. The first
**  byte is the length byte. The actual string starts at [1] and the
**  string is NOT NUL terminated.
*/

  /* Status */

#define ISZC        1
#define ISRC        2
#define ISNC        3
#define ISHUB       4
#define ISPVT       5
#define ISHOLD      6
#define ISDOWN      7
#define ISPOINT     9

  /* Capability flags */

#define CMflag      0x00000002L
#define MOflag      0x00000004L
#define HSTflag     0x00000008L
#define H96flag     0x00000010L
#define PEPflag     0x00000020L
#define MAXflag     0x00000040L
#define XXflag      0x00000080L
#define XBflag      0x00000100L
#define XRflag      0x00000200L
#define XPflag      0x00000400L
#define XWflag      0x00000800L
#define MNPflag     0x00001000L
#define HST14flag   0x00002000L
#define V32flag     0x00004000L
#define V33flag     0x00008000L
#define V34flag     0x00010000L
#define V42flag     0x00020000L
#define XCflag      0x00040000L
#define XAflag      0x00080000L
#define V42bflag    0x00100000L
#define V32bflag    0x00200000L
#define HST16flag   0x00400000L
#define LOflag      0x00800000L
#define ZYXflag     0x01000000L
#define UISDNAflag  0x02000000L
#define UISDNBflag  0x04000000L
#define UISDNCflag  0x08000000L
#define FAXflag     0x10000000L

  /* MaxBaud field */

#define ISBAUD300       2
#define ISBAUD1200      4
#define ISBAUD2400      5
#define ISBAUD4800      6
#define ISBAUD7200      10
#define ISBAUD9600      7
#define ISBAUD12000     11
#define ISBAUD14400     12
#define ISBAUD16800     13
#define ISBAUD19200     14
#define ISBAUD38400     15
#define ISBAUD57600     16
#define ISBAUD64000     17
#define ISBAUD76800     18
#define ISBAUD115200    19

  /* Record structure */

  /* Note that while the private database can only hold a fixed amount of
     information about a system's capabilities (nodelist flags), FrontDoor
     is capable of using the actual string present in FidoNet-style node-
     lists for routing and other lookup purposes. */

typedef struct
    {
    long                  Erased;             /*Used to signal erased status*/
    unsigned char         Status;                    /*Zone, host, hub, etc.*/
    unsigned short int    NodeNo,                          /*Network address*/
                          NetNo,
                          Zone,
                          Point,
                          RoutNode,            /*Default routing within zone*/
                          RoutNet,
                          Cost;                 /*Cost per minute for system*/
    long                  Capability;                     /*Capability flags*/
    unsigned char         MaxBaud;                       /*Maximum baud rate*/
    char                  Name[31];                         /*Name of system*/
    char                  Telephone[41];              /*Raw telephone number*/
    char                  Location[41];                 /*Location of system*/
    char                  User[37];                             /*SysOp name*/
    char                  SelectTag[4];                        /*Group field*/
    }
    NODEREC;

/*
**  The telephone number database (FDPHONE.FDA) has the following record
**  format. Note that the char[] fields are in Pascal fashion. The first
**  byte is the length byte. The actual string starts at [1] and the
**  string is NOT NUL terminated.
*/
typedef struct
    {
    long                  Erased;             /*Used to signal erased status*/
    char                  Telephone[41];          /*Phone number translation*/
    unsigned short int    Cost;                   /*Cost per minute of calls*/
    unsigned short int    Baudrate;             /*Max baudrate for this area*/
    }
    PHONEREC;

/*
**  The nodelist index file (NODELIST.FDX) has the following record
**  format. Note that the char[] fields are in Pascal fashion. The first
**  byte is the length byte. The actual string starts at [1] and the
**  string is NOT NUL terminated.
*/
typedef struct
    {
    unsigned char         Length;               /*Length byte for key string*/
    unsigned short int    Zone,                   /*Swapped zone for sorting*/
                          Net,                     /*Swapped net for sorting*/
                          Node,                   /*Swapped node for sorting*/
                          Point,                 /*Swapped point for sorting*/
                          RoutNet,             /*Default routing within zone*/
                          RoutNode;
    unsigned char         Status;                                /*See above*/
    unsigned char         RESERVED;                               /*Reserved*/
    }
    NODEIDXREC;

/*
**  The userlist index file (USERLIST.FDX) has the following record
**  format. Note that the char[] fields are in Pascal fashion. The first
**  byte is the length byte. The actual string starts at [1] and the
**  string is NOT NUL terminated.
*/
typedef union
    {
    char                NameIt[37];             /*To facilitate use of moves*/
    struct
        {
        char            User[16];                   /*Actual name key length*/
        unsigned short int
                        Zone,                       /*To return address info*/
                        Net,
                        Node,
                        Point;
        unsigned char   Status;                     /*Node status, see above*/
        }
        NodeInfo;
    }
    USERIDXREC;

#ifdef __cplusplus
}
#endif
#endif

/* end of file "nodelist.h" */

